@@ -8,8 +8,8 @@
 #
 package PerlIO::via::Timeout::Strategy;
 {
-  $PerlIO::via::Timeout::Strategy::VERSION = '0.13';
-} # hide from CPAN
+  $PerlIO::via::Timeout::Strategy::VERSION = '0.14';
+}
 
 # ABSTRACT: base class for a L<PerlIO::via::Timeout> strategies
 
@@ -21,7 +21,7 @@ use Carp;
 sub new {
     my $class = shift;
     @_ % 2 and croak "parameters should be key value pairs";
-    my $self = bless { read_timeout => 0, write_timeout => 0, @_ }, $class;
+    my $self = bless { read_timeout => 0, write_timeout => 0, timeout_enabled => 1, @_ }, $class;
     $self->_check_attributes;
     $self;
 }
@@ -39,6 +39,14 @@ sub read_timeout {
 sub write_timeout {
     @_ > 1 and $_[0]{write_timeout} = $_[1], $_[0]->_check_attributes;
     $_[0]{write_timeout};    
+
+sub timeout_enabled {
+    @_ > 1 and $_[0]{timeout_enabled} = !!$_[1];
+    $_[0]{timeout_enabled};
+}
+
+sub enable_timeout { $_[0]->timeout_enabled(1) }
+sub disable_timeout { $_[0]->timeout_enabled(0) }
 }
 
 sub READ { croak "READ is not implemented by this strategy" }
@@ -56,7 +64,7 @@ PerlIO::via::Timeout::Strategy - base class for a L<PerlIO::via::Timeout> strate
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
