@@ -8,7 +8,7 @@
 #
 package PerlIO::via::Timeout::Strategy::Select;
 {
-  $PerlIO::via::Timeout::Strategy::Select::VERSION = '0.13';
+  $PerlIO::via::Timeout::Strategy::Select::VERSION = '0.14';
 }
 
 # ABSTRACT: a L<PerlIO::via::Timeout> strategy that uses C<select>
@@ -19,15 +19,17 @@ use warnings;
 use Carp;
 use Errno qw(EINTR ETIMEDOUT);
 
-use PerlIO::via::Timeout::Strategy::NoTimeout;
-our @ISA = qw(PerlIO::via::Timeout::Strategy::NoTimeout);
+use parent qw(PerlIO::via::Timeout::Strategy::NoTimeout);
 
 
 
 sub READ {
     my ($self, undef, $len, $fh, $fd) = @_;
 
-    my $read_timeout = $self->{read_timeout}
+    $self->timeout_enabled
+      or return shift->SUPER::READ(@_);
+
+    my $read_timeout = $self->read_timeout
       or return shift->SUPER::READ(@_);
 
     my $offset = 0;
@@ -52,7 +54,10 @@ sub READ {
 sub WRITE {
     my ($self, undef, $fh, $fd) = @_;
 
-    my $write_timeout = $self->{write_timeout}
+    $self->timeout_enabled
+      or return shift->SUPER::WRITE(@_);
+
+    my $write_timeout = $self->write_timeout
       or return shift->SUPER::WRITE(@_);
 
     my $len = length $_[1];
@@ -117,14 +122,13 @@ PerlIO::via::Timeout::Strategy::Select - a L<PerlIO::via::Timeout> strategy that
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
-  my $strategy = PerlIO::via::Timeout::Strategy::Select->new(
-      read_timeout => 1,
-      write_timeout => 2,
-  );
+  use PerlIO::via::Timeout qw(timeout_strategy);
+  binmode($fh, ':via(Timeout)');
+  timeout_strategy($fh, 'Select', read_timeout => 0.5);
 
 =head1 DESCRIPTION
 
@@ -148,6 +152,10 @@ The read timeout in second. Can be a float
 
 The write timeout in second. Can be a float
 
+=item timeout_enabled
+
+Boolean. Defaults to 1
+
 =back
 
 =head1 SEE ALSO
